@@ -1,7 +1,7 @@
 package Devel::Chitin::OpTree::LISTOP;
 use base Devel::Chitin::OpTree::BINOP;
 
-use Devel::Chitin::Version;
+our $VERSION = '0.08';
 
 use Fcntl qw(:DEFAULT :flock SEEK_SET SEEK_CUR SEEK_END);
 use POSIX qw(:sys_wait_h);
@@ -321,7 +321,6 @@ sub _deparse_seeklike {
 sub _generate_flag_list {
     map { local $@;
           my $val = eval "$_";
-print STDERR "*** in generate_flag_list(), $_ threw exception: $@\n" if $@;
           $val ? ( $_ => $val ) : ()
     } @_
 }
